@@ -49,8 +49,8 @@ class Interface:
                  capture_session=False, interpretation=None,
                  title=None, description=None, article=None, thumbnail=None, 
                  css=None, server_port=7860, server_name=networking.LOCALHOST_NAME,
-                 allow_screenshot=True, allow_flagging=True, show_tips=True,
-                 embedding=None, flagging_dir="flagged", analytics_enabled=True):
+                 allow_screenshot=True, allow_flagging=True, flagging_options=None,
+                 show_tips=True, embedding=None, flagging_dir="flagged", analytics_enabled=True):
 
         """
         Parameters:
@@ -73,6 +73,7 @@ class Interface:
         server_name (str): to make app accessible on local network set to "0.0.0.0".
         allow_screenshot (bool): if False, users will not see a button to take a screenshot of the interface.
         allow_flagging (bool): if False, users will not see a button to flag an input and output.
+        flagging_options (List[str]): if not None, provides options a user must select when flagging.
         flagging_dir (str): what to name the dir where flagged data is stored.
         show_tips (bool): if True, will occasionally show tips about new Gradio features
         """
@@ -127,6 +128,7 @@ class Interface:
         self.title = title
         self.description = description
         if article is not None:
+            article = utils.readme_to_html(article)
             article = markdown2.markdown(article)
         self.article = article
         self.thumbnail = thumbnail
@@ -135,12 +137,16 @@ class Interface:
                 self.css = css_file.read()
         else:
             self.css = css
-        self.examples = examples
+        if examples is None or isinstance(examples, str) or (isinstance(examples, list) and (len(examples) == 0 or isinstance(examples[0], list))):
+            self.examples = examples
+        else:
+            raise ValueError("Examples argument must either be a directory or a nested list, where each sublist represents a set of inputs.")
         self.examples_per_page = examples_per_page
         self.server_port = server_port
         self.simple_server = None
         self.allow_screenshot = allow_screenshot
         self.allow_flagging = os.getenv("GRADIO_FLAGGING") or allow_flagging
+        self.flagging_options = flagging_options 
         self.flagging_dir = flagging_dir
         Interface.instances.add(self)
         self.analytics_enabled=analytics_enabled
@@ -177,8 +183,8 @@ class Interface:
         if self.analytics_enabled:
             try:
                 requests.post(analytics_url + 'gradio-initiated-analytics/',
-                              data=data)
-            except requests.ConnectionError:
+                              data=data, timeout=3)
+            except (requests.ConnectionError, requests.exceptions.ReadTimeout):
                 pass  # do not push analytics if no network
 
     def get_config_file(self):
@@ -201,6 +207,7 @@ class Interface:
             "thumbnail": self.thumbnail,
             "allow_screenshot": self.allow_screenshot,
             "allow_flagging": self.allow_flagging,
+            "flagging_options": self.flagging_options,
             "allow_interpretation": self.interpretation is not None,
             "allow_embedding": self.embedding is not None,
         }
@@ -221,14 +228,8 @@ class Interface:
                     
         except ValueError:
             pass
-        if self.examples is not None:
-            processed_examples = []
-            for example_set in self.examples:
-                processed_set = []
-                for iface, example in zip(self.input_interfaces, example_set):
-                    processed_set.append(example)
-                processed_examples.append(processed_set)
-            config["examples"] = processed_examples
+        if self.examples is not None and not isinstance(self.examples, str):
+            config["examples"] = self.examples
         return config
 
     def run_prediction(self, processed_input, return_duration=False):
@@ -402,10 +403,11 @@ class Interface:
         is_colab = utils.colab_check()
         if is_colab or not(networking.url_ok(path_to_local_server)):  
             share = True
-            if debug:
-                print(strings.en["COLAB_DEBUG_TRUE"])
-            else:
-                print(strings.en["COLAB_DEBUG_FALSE"])
+            if is_colab:
+                if debug:
+                    print(strings.en["COLAB_DEBUG_TRUE"])
+                else:
+                    print(strings.en["COLAB_DEBUG_FALSE"])
         else:
             print(strings.en["RUNNING_LOCALLY"].format(path_to_local_server))
 
@@ -496,8 +498,8 @@ def send_error_analytics(analytics_enabled):
     if analytics_enabled:
         try:
             requests.post(analytics_url + 'gradio-error-analytics/',
-                            data=data)
-        except requests.ConnectionError:
+                            data=data, timeout=3)
+        except (requests.ConnectionError, requests.exceptions.ReadTimeout):
             pass  # do not push analytics if no network
 
 def send_launch_analytics(analytics_enabled, inbrowser, is_colab, share, share_url):
@@ -512,8 +514,8 @@ def send_launch_analytics(analytics_enabled, inbrowser, is_colab, share, share_u
         }
         try:
             requests.post(analytics_url + 'gradio-launched-analytics/',
-                            data=data)
-        except requests.ConnectionError:
+                            data=data, timeout=3)
+        except (requests.ConnectionError, requests.exceptions.ReadTimeout):
             pass  # do not push analytics if no network
 
 
