@@ -51,8 +51,8 @@ cli.show_server_banner = lambda *x: None
 
 def get_local_ip_address():
     try:
-        ip_address = requests.get('https://api.ipify.org').text
-    except requests.ConnectionError:
+        ip_address = requests.get('https://api.ipify.org', timeout=3).text
+    except (requests.ConnectionError, requests.exceptions.ReadTimeout):
         ip_address = "No internet connection"
     return ip_address
 
@@ -79,15 +79,21 @@ def get_first_available_port(initial, final):
         )
     )
 
-
-@app.route("/", methods=["GET"])
-def main():
+def home_page(examples=None, path=None):
     return render_template("index.html",
         config=app.interface.config,
         vendor_prefix=(GRADIO_STATIC_ROOT if app.interface.share else ""),
-        css=app.interface.css,
+        input_interfaces=[interface[0] for interface in app.interface.config["input_interfaces"]],
+        output_interfaces=[interface[0] for interface in app.interface.config["output_interfaces"]],
+        css=app.interface.css, examples=examples, path=path
     )
 
+@app.route("/", methods=["GET"])
+def main():
+    if isinstance(app.interface.examples, str):
+        return redirect("/from_dir/" + app.interface.examples)
+    return home_page()
+
 @app.route("/from_dir", methods=["GET"])
 def main_from_flagging_dir():
     return redirect("/from_dir/" + app.interface.flagging_dir)
@@ -96,19 +102,17 @@ def main_from_flagging_dir():
 def main_from_dir(path):
     log_file = os.path.join(path, "log.csv")
     if not os.path.exists(log_file):
-        abort(404)
+        if isinstance(app.interface.examples, str):
+            abort(404, "Examples dir not found")
+        else:
+            redirect("/")
     with open(log_file) as logs:
         examples = list(csv.reader(logs)) 
     examples = examples[1:] #remove header
-    input_examples = [example[:len(app.interface.input_interfaces)] for example in examples]
-    return render_template("index.html",
-        config=app.interface.config,
-        vendor_prefix=(GRADIO_STATIC_ROOT if app.interface.share else ""),
-        css=app.interface.css,
-        path=path,
-        examples=input_examples
-    )
-
+    for i, example in enumerate(examples):
+        for j, (interface, cell) in enumerate(zip(app.interface.input_interfaces + app.interface.output_interfaces, example)):
+            examples[i][j] = interface.restore_flagged(cell)
+    return home_page(examples=examples, path=path)
 
 @app.route("/config/", methods=["GET"])
 def config():
@@ -141,8 +145,8 @@ def log_feature_analytics(feature):
             requests.post(GRADIO_FEATURE_ANALYTICS_URL, 
             data={
                 'ip_address': IP_ADDRESS,
-                'feature': feature})
-        except requests.ConnectionError:
+                'feature': feature}, timeout=3)
+        except (requests.ConnectionError, requests.exceptions.ReadTimeout):
             pass  # do not push analytics if no network
 
 @app.route("/api/score_similarity/", methods=["POST"])
@@ -217,11 +221,15 @@ def predict_examples():
     return jsonify(output)
 
 
-def flag_data(data):
+def flag_data(input_data, output_data, flag_option=None):
     flag_path = os.path.join(app.cwd, app.interface.flagging_dir)
-    output = [app.interface.input_interfaces[i].rebuild(
-            flag_path, component_data)
-            for i, component_data in enumerate(data)]
+    csv_data = []
+    for i, interface in enumerate(app.interface.input_interfaces):
+        csv_data.append(interface.save_flagged(flag_path, app.interface.config["input_interfaces"][i][1]["label"], input_data[i]))
+    for i, interface in enumerate(app.interface.output_interfaces):
+        csv_data.append(interface.save_flagged(flag_path, app.interface.config["output_interfaces"][i][1]["label"], output_data[i]))
+    if flag_option:
+        csv_data.append(flag_option)
 
     log_fp = "{}/log.csv".format(flag_path)
     is_new = not os.path.exists(log_fp)
@@ -230,15 +238,18 @@ def flag_data(data):
         writer = csv.writer(csvfile)
         if is_new:
             headers = [interface[1]["label"] for interface in app.interface.config["input_interfaces"]]
+            headers += [interface[1]["label"] for interface in app.interface.config["output_interfaces"]]
+            if app.interface.flagging_options is not None:
+                headers.append("flag")
             writer.writerow(headers)
 
-        writer.writerow(output)
+        writer.writerow(csv_data)
 
 @app.route("/api/flag/", methods=["POST"])
 def flag():
     log_feature_analytics('flag')
-    data = request.json['data']['input_data']
-    flag_data(data)
+    data = request.json['data']
+    flag_data(data['input_data'], data['output_data'], data.get("flag_option"))
     return jsonify(success=True)
 
 
@@ -264,9 +275,9 @@ def start_server(interface, server_name, server_port=None, auth=None):
         server_port, server_port + TRY_NUM_PORTS
     )
     if auth is not None:
-        app.interface.config['BASIC_AUTH_USERNAME'] = auth[0]
-        app.interface.config['BASIC_AUTH_PASSWORD'] = auth[1]
-        app.interface.config['BASIC_AUTH_FORCE'] = True
+        app.config['BASIC_AUTH_USERNAME'] = auth[0]
+        app.config['BASIC_AUTH_PASSWORD'] = auth[1]
+        app.config['BASIC_AUTH_FORCE'] = True
         basic_auth = BasicAuth(app)        
     app.interface = interface
     app.cwd = os.getcwd()
@@ -309,7 +320,10 @@ def setup_tunnel(local_server_port):
 
 def url_ok(url):
     try:
-        r = requests.head(url)
-        return r.status_code == 200 or r.status_code == 401
-    except ConnectionError:
+        for _ in range(5):
+            time.sleep(.500)
+            r = requests.head(url, timeout=3)
+            if r.status_code == 200 or r.status_code == 401: # 401 if auth is set
+                return True
+    except (ConnectionError, requests.exceptions.ConnectionError):
         return False
